@@ -1,21 +1,21 @@
 description_NCAcsv<-function(replicated=FALSE, parallel=FALSE){
 cat("****************************************************************************\n")
-cat(" Data file should consist of                                               \n")
+cat(" Input data file should consist of the following:                           \n")
 cat("---------------------------------------------------------------------------\n")
 if(parallel){
-cat("    row#1: column title, such as subj, drug, time, conc & etc.         \n")
+cat(" row#1: column title, such as subj, drug (trt), time & Conc.                \n")
 }
 else{
  if(replicated){
-cat("    row#1: column title, such as subj, seq, prd, drug, time, conc & etc.  \n")
+cat(" row#1: column title, such as subj, seq, prd, drug (trt), time & Conc.     \n")
  }
  else{
-cat("    row#1: column title, such as subj, seq, prd, time, conc & etc.         \n")
+cat("    row#1: column title, such as subj, seq, prd, time & Conc.             \n")
  }
 } 
 cat(" column#1: subject no.(subj)                                               \n")
 if(parallel){
-cat(" column#2: treatment (drug)                                                \n")
+cat(" column#2: treatment (trt or drug)                                         \n")
 cat(" column#3: sampling time                                                   \n")
 cat(" column#4: drug plasma/serum/blood concentration (conc)                    \n")
 }
@@ -29,7 +29,7 @@ cat("             -> i.e. prd = 1: the 1st-treatment period
 cat("             ->      prd = 2: the 2nd-treatment period                     \n")
 cat("             ->      prd = 3: the 3rd-treatment period                     \n")
 cat("             ->      prd = 4: the 4th-treatment period                     \n")
-cat(" column#4: treatment (drug)                                                \n")
+cat(" column#4: treatment (trt or drug)                                         \n")
 cat(" column#5: sampling time                                                   \n")
 cat(" column#6: drug plasma/serum/blood concentration (conc)                    \n")
   }
